==> gosa-2.0.1.tar.gz: gosa-2.0.1/include/egosa.php <==
<?php
	if(isset($_SESSION["js"])){
		if (!isset($_SESSION{'eGosa'})){
?>
<center><a href="main.php?<?php if (isset($_GET['plug'])) print("plug=".$_GET['plug']."&"); ?>explorer=1" onMouseOver="document.images['activate'].src='/egosa/images/activate_.jpg'"  onMouseOut="document.images['activate'].src='/egosa/images/activate.jpg'"><img name="activate" src="/egosa/images/activate.jpg" border="0"></a></center>
<?php
			global $plist;
			echo $plist->show_menu();
		}else{
?>
<!-- eGosa explorer Applet -->
	<script language="JavaScript" src="/egosa/js/cookie.js"></script>
	<OBJECT
		ID="eGosa"
		classid = "clsid:CAFEEFAC-0014-0002-0000-ABCDEFFEDCBA"
		width="200" height="520" align="baseline"
		codebase = "http://java.sun.com/products/plugin/autodl/jinstall-1_4_2-windows-i586.cab#Version=1,4,2,0" >
		<PARAM NAME="code" VALUE="org.gonicus.egosa.egosa">
		<PARAM NAME="name" VALUE="eGosa">
		<PARAM NAME="codebase" VALUE="/egosa/java/">
		<PARAM NAME="type" VALUE="application/x-java-applet;version\=1.4">
		<PARAM NAME="scriptable" VALUE="true">
		<PARAM NAME="archive" VALUE="egosa.jar, xmlrpc-1.1.jar">
		<PARAM NAME="cache_archive" VALUE="egosa.jar, xmlrpc-1.1.jar">
		<PARAM NAME="MAYSCRIPT" VALUE="true">
		<COMMENT>
		<EMBED ID="eGosa" type="application/x-java-applet;version=1.4" width="200"
			align="baseline" code="org.gonicus.egosa.egosa" height="520"
			codebase="/egosa/java/"
			archive="egosa.jar, egosalibs.jar, xmlrpc-1.1.jar"
			cache_archive="egosa.jar, egosalibs.jar, xmlrpc-1.1.jar"
			MAYSCRIPT=true
			pluginspage="http://java.sun.com/products/plugin/1.4/plugin-install.html">
			<NOEMBED>
			No Java 2 SDK, Standard Edition v 1.4 support for APPLET!!
			</NOEMBED>
		</EMBED>
		</COMMENT>
	</OBJECT>
<?php
		}
	}
?>

==> gosa-2.2.tar.gz: gosa-2.2/include/egosa.php <==
<?php
	if(isset($_SESSION["js"])){
		if (!isset($_SESSION{'eGosa'})){
?>
<center><a href="main.php?<?php if (isset($_GET['plug'])) print("plug=".$_GET['plug']."&"); ?>explorer=1" onMouseOver="document.images['activate'].src='/egosa/images/activate_.jpg'"  onMouseOut="document.images['activate'].src='/egosa/images/activate.jpg'"><img name="activate" src="/egosa/images/activate.jpg" border="0"></a></center>
<?php
			#global $plist;
			#echo $plist->show_menu();
		}else{
?>
<!-- eGosa explorer Applet -->
	<script language="JavaScript" src="/egosa/js/cookie.js" type="text/javascript"></script>
	<OBJECT
		ID="eGosa"
		classid = "clsid:CAFEEFAC-0014-0002-0000-ABCDEFFEDCBA"
		width="200" height="520" align="baseline"
		codebase = "http://java.sun.com/products/plugin/autodl/jinstall-1_4_2-windows-i586.cab#Version=1,4,2,0" >
		<PARAM NAME="code" VALUE="org.gonicus.egosa.egosa">
		<PARAM NAME="name" VALUE="eGosa">
		<PARAM NAME="codebase" VALUE="/egosa/java/">
		<PARAM NAME="type" VALUE="application/x-java-applet;version\=1.4">
		<PARAM NAME="scriptable" VALUE="true">
		<PARAM NAME="archive" VALUE="egosa.jar, xmlrpc-1.1.jar">
		<PARAM NAME="cache_archive" VALUE="egosa.jar, xmlrpc-1.1.jar">
		<PARAM NAME="MAYSCRIPT" VALUE="true">
		<COMMENT>
		<EMBED ID="eGosa" type="application/x-java-applet;version=1.4" width="200"
			align="baseline" code="org.gonicus.egosa.egosa" height="520"
			codebase="/egosa/java/"
			archive="egosa.jar, egosalibs.jar, xmlrpc-1.1.jar"
			cache_archive="egosa.jar, egosalibs.jar, xmlrpc-1.1.jar"
			MAYSCRIPT=true
			pluginspage="http://java.sun.com/products/plugin/1.4/plugin-install.html">
			<NOEMBED>
			No Java 2 SDK, Standard Edition v 1.4 support for APPLET!!
			</NOEMBED>
		</EMBED>
		</COMMENT>
	</OBJECT>
<?php
		}
	}
?>
